@@ -2096,12 +2096,13 @@ class Element(ElementBase):
         parent_xpath = self._get_xpath()
         return f"{parent_xpath}/*[{index}]"
 
-    def wait(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits for the element to appear (present in DOM).
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Frequency of polling.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element is found, False otherwise.
@@ -2111,20 +2112,27 @@ class Element(ElementBase):
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
                 self.logger.error("Resolved locator is None or invalid")
-                return False
+                if return_bool:
+                    return False
+                return cast('Element', self)
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.present(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
-    def wait_visible(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait_visible(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits until the element is visible.
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Frequency of polling.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element becomes visible, False otherwise.
@@ -2134,21 +2142,28 @@ class Element(ElementBase):
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
                 self.logger.error("Resolved locator is None or invalid")
-                return False
+                if return_bool:
+                    return False
+                return cast('Element', self)
 
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.visible(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
-    def wait_clickable(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait_clickable(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits until the element is clickable.
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Frequency of polling.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element becomes clickable, False otherwise.
@@ -2158,21 +2173,28 @@ class Element(ElementBase):
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
                 self.logger.error("Resolved locator is None or invalid")
-                return False
+                if return_bool:
+                    return False
+                return cast('Element', self)
 
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.clickable(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
-    def wait_for_not(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait_for_not(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits until the element is no longer present in the DOM.
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Frequency of polling.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element disappears, False otherwise.
@@ -2181,21 +2203,27 @@ class Element(ElementBase):
         try:
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
-                self.logger.error("Resolved locator is None or invalid")
-                return True
+                if return_bool:
+                    return False
+                return cast('Element', self)
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.not_present(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
-    def wait_for_not_visible(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait_for_not_visible(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits until the element becomes invisible.
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Polling frequency.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element becomes invisible, False otherwise.
@@ -2204,21 +2232,27 @@ class Element(ElementBase):
         try:
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
-                self.logger.error("Resolved locator is None or invalid")
-                return True
+                if return_bool:
+                    return False
+                return cast('Element', self)
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.not_visible(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
-    def wait_for_not_clickable(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+    def wait_for_not_clickable(self, timeout: int = 10, poll_frequency: float = 0.5, return_bool: bool = False) -> Union[bool, 'Element']:
         """Waits until the element becomes not clickable.
 
         Args:
             timeout (int): Timeout in seconds.
             poll_frequency (float): Polling frequency.
+            return_bool (bool): If True - return bool, else return Element (self)
 
         Returns:
             bool: True if the element becomes not clickable, False otherwise.
@@ -2228,13 +2262,19 @@ class Element(ElementBase):
             resolved_locator = self.handle_locator(self.locator, self.contains)
             if not resolved_locator:
                 self.logger.error("Resolved locator is None or invalid")
-                return True
+                if return_bool:
+                    return False
+                return cast('Element', self)
             WebDriverWait(self.base.driver, timeout, poll_frequency).until(
                 conditions.not_clickable(resolved_locator)
             )
-            return True
+            if return_bool:
+                return True
+            return cast('Element', self)
         except TimeoutException:
-            return False
+            if return_bool:
+                return False
+            return cast('Element', self)
 
     @property
     def should(self) -> 'Should':
